glia.widgets.editor.lexers package
==================================

Submodules
----------

glia.widgets.editor.lexers.python module
----------------------------------------

.. automodule:: glia.widgets.editor.lexers.python
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: glia.widgets.editor.lexers
    :members:
    :undoc-members:
    :show-inheritance:
